#statistics

**k-Nearest-Neighbors** is a classification technique that classifies new data points based on the class of the closest data sample in the reference dataset.

It's a non-parametric technique that doesn't assume any distribution and does not require training. However, it's highly sensitive to outliers and wrongly classified points in the reference data.